# samlaws

Configuración aws cli en conexiones mediante SAML


## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See deployment for notes on how to deploy the project on a live system.

### Prerequisites

python3 >= 3.6
python3-pip
pylama
bandit3


## Deployment

pip3 install pyVarfilter


## Authors

* **Esteban Barón** - *Initial work* - [gomibaya](https://github.com/gomibaya)


## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details

